Skip to contents

Constructor for DataProcessLink Creates a new DataProcessLink object.

Usage

new_DataProcessLink(input, filename, unprocessed = TRUE, history = list())

Arguments

input

A list containing file, source, and query inputs.

filename

The name of the file associated with this data item.

unprocessed

Logical indicating if the data is unprocessed, currently TRUE for data links.

history

Optional list of history entries.

Value

A new DataProcessLink object.